@@ -1,21 +1,17 @@
-# Copyright (C) 2011 Vaadin Ltd.
-# Copyright (C) 2011 Richard Lincoln
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as published
-# by the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
-# Note: This is a modified file from Vaadin. For further information on
-#       Vaadin please visit http://www.vaadin.com.
+# Copyright (C) 2012 Vaadin Ltd. 
+# Copyright (C) 2012 Richard Lincoln
+# 
+# Licensed under the Apache License, Version 2.0 (the "License"); 
+# you may not use this file except in compliance with the License. 
+# You may obtain a copy of the License at 
+# 
+#     http://www.apache.org/licenses/LICENSE-2.0 
+# 
+# Unless required by applicable law or agreed to in writing, software 
+# distributed under the License is distributed on an "AS IS" BASIS, 
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
+# See the License for the specific language governing permissions and 
+# limitations under the License.
 
 """Defines a base class required for all Muntjac applications."""
 
@@ -36,6 +32,7 @@ from muntjac.terminal.uri_handler import IErrorEvent as URIHandlerErrorEvent
 from muntjac.terminal.parameter_handler import IErrorEvent as ParameterHandlerErrorEvent
 from muntjac.terminal.gwt.server.change_variables_error_event import ChangeVariablesErrorEvent
 from muntjac.ui.abstract_component import AbstractComponent
+from muntjac.ui.window import Window
 from muntjac.messages import SystemMessages
 
 
@@ -80,7 +77,7 @@ class Application(IUriHandler, ITerminal, IErrorListener):
 
     @author: Vaadin Ltd.
     @author: Richard Lincoln
-    @version: 1.0.4
+    @version: 1.1.0
     """
 
     #: The default SystemMessages (read-only). Change by overriding
@@ -821,7 +818,7 @@ class Application(IUriHandler, ITerminal, IErrorListener):
         t = event.getThrowable()
         if isinstance(t, IOError):  #SocketException
             # Most likely client browser closed socket
-            logger.info('SocketException in CommunicationManager.' \
+            logger.exception('SocketException in CommunicationManager.' \
                               ' Most likely client (browser) closed socket.')
             return
 
@@ -904,7 +901,7 @@ class UserChangeEvent(EventObject):
     Application user change event sent when the setUser is called to change
     the current user of the application.
 
-    @version: 1.0.4
+    @version: 1.1.0
     """
 
     def __init__(self, source, newUser, prevUser):
@@ -955,7 +952,7 @@ class IUserChangeListener(IEventListener):
     """The C{UserChangeListener} interface for listening application
     user changes.
 
-    @version: 1.0.4
+    @version: 1.1.0
     """
 
     def applicationUserChanged(self, event):
@@ -1074,3 +1071,21 @@ class ApplicationError(IErrorEvent):
 
     def getThrowable(self):
         return self._throwable
+
+
+class SingletonApplication(Application):
+
+    _singleton = None
+
+    def __init__(self):
+        super(SingletonApplication, self).__init__()
+        self.setMainWindow(Window())
+
+    @classmethod
+    def get(cls):
+        if cls._singleton is None:
+            cls._singleton = SingletonApplication()
+        return cls._singleton
+
+    def init(self):
+        pass
