@@ -1,21 +1,17 @@
-# Copyright (C) 2011 Vaadin Ltd.
-# Copyright (C) 2011 Richard Lincoln
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as published
-# by the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
-# Note: This is a modified file from Vaadin. For further information on
-#       Vaadin please visit http://www.vaadin.com.
+# Copyright (C) 2012 Vaadin Ltd. 
+# Copyright (C) 2012 Richard Lincoln
+# 
+# Licensed under the Apache License, Version 2.0 (the "License"); 
+# you may not use this file except in compliance with the License. 
+# You may obtain a copy of the License at 
+# 
+#     http://www.apache.org/licenses/LICENSE-2.0 
+# 
+# Unless required by applicable law or agreed to in writing, software 
+# distributed under the License is distributed on an "AS IS" BASIS, 
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
+# See the License for the specific language governing permissions and 
+# limitations under the License.
 
 """Defines a servlet that connects a Muntjac Application to Web."""
 
@@ -30,7 +26,7 @@ class ApplicationServlet(AbstractApplicationServlet):
 
     @author: Vaadin Ltd.
     @author: Richard Lincoln
-    @version: 1.0.4
+    @version: 1.1.0
     """
 
     def __init__(self, applicationClass, *args, **kw_args):
@@ -85,3 +81,21 @@ class ApplicationServlet(AbstractApplicationServlet):
 
     def getApplicationClass(self):
         return self._applicationClass
+
+
+class SingletonApplicationServlet(AbstractApplicationServlet):
+
+    def __init__(self, applicationObject, *args, **kw_args):
+        super(SingletonApplicationServlet, self).__init__(*args, **kw_args)
+        self._applicationObject = applicationObject
+
+
+    def getNewApplication(self, request):
+        if self._applicationObject is not None:
+            return self._applicationObject
+        else:
+            raise ServletException, "getNewApplication failed"
+
+
+    def getApplicationClass(self):
+        return self._applicationObject.__class__
