@@ -1,21 +1,17 @@
-# Copyright (C) 2011 Vaadin Ltd.
-# Copyright (C) 2011 Richard Lincoln
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as published
-# by the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
-# Note: This is a modified file from Vaadin. For further information on
-#       Vaadin please visit http://www.vaadin.com.
+# Copyright (C) 2012 Vaadin Ltd. 
+# Copyright (C) 2012 Richard Lincoln
+# 
+# Licensed under the Apache License, Version 2.0 (the "License"); 
+# you may not use this file except in compliance with the License. 
+# You may obtain a copy of the License at 
+# 
+#     http://www.apache.org/licenses/LICENSE-2.0 
+# 
+# Unless required by applicable law or agreed to in writing, software 
+# distributed under the License is distributed on an "AS IS" BASIS, 
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
+# See the License for the specific language governing permissions and 
+# limitations under the License.
 
 """Defines a container that consists of components with certain coordinates
 on a grid."""
@@ -53,7 +49,7 @@ class GridLayout(AbstractLayout, IAlignmentHandler, ISpacingHandler,
 
     @author: Vaadin Ltd.
     @author: Richard Lincoln
-    @version: 1.0.4
+    @version: 1.1.0
     """
 
     CLIENT_WIDGET = None #ClientWidget(VGridLayout, LoadStyle.EAGER)
@@ -213,7 +209,7 @@ class GridLayout(AbstractLayout, IAlignmentHandler, ISpacingHandler,
             # component.setParent(this);
             index = 0
             done = False
-            while not done and index < len(self._areas):
+            while not done and (index < len(self._areas)):
                 existingArea = self._areas[index]
                 if ((existingArea._row1 >= row1
                         and existingArea._column1 > column1)
@@ -955,7 +951,7 @@ class Area(object):
 
     @author: Vaadin Ltd.
     @author: Richard Lincoln
-    @version: 1.0.4
+    @version: 1.1.0
     """
 
     def __init__(self, component, column1, row1, column2, row2):
@@ -1105,7 +1101,7 @@ class OverlapsException(RuntimeError):
 
     @author: Vaadin Ltd.
     @author: Richard Lincoln
-    @version: 1.0.4
+    @version: 1.1.0
     """
 
     def __init__(self, existingArea):
@@ -1153,7 +1149,7 @@ class OutOfBoundsException(RuntimeError):
 
     @author: Vaadin Ltd.
     @author: Richard Lincoln
-    @version: 1.0.4
+    @version: 1.1.0
     """
 
     def __init__(self, areaOutOfBounds):
