@@ -1,21 +1,17 @@
-# Copyright (C) 2011 Vaadin Ltd.
-# Copyright (C) 2011 Richard Lincoln
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Affero General Public License as published
-# by the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
-# Note: This is a modified file from Vaadin. For further information on
-#       Vaadin please visit http://www.vaadin.com.
+# Copyright (C) 2012 Vaadin Ltd. 
+# Copyright (C) 2012 Richard Lincoln
+# 
+# Licensed under the Apache License, Version 2.0 (the "License"); 
+# you may not use this file except in compliance with the License. 
+# You may obtain a copy of the License at 
+# 
+#     http://www.apache.org/licenses/LICENSE-2.0 
+# 
+# Unless required by applicable law or agreed to in writing, software 
+# distributed under the License is distributed on an "AS IS" BASIS, 
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
+# See the License for the specific language governing permissions and 
+# limitations under the License.
 
 """Defines a component for showing non-editable short texts."""
 
@@ -54,7 +50,7 @@ class Label(AbstractComponent, prop.IProperty, prop.IViewer,
 
     @author: Vaadin Ltd.
     @author: Richard Lincoln
-    @version: 1.0.4
+    @version: 1.1.0
     """
 
     CLIENT_WIDGET = None #ClientWidget(VLabel, LoadStyle.EAGER)
@@ -372,7 +368,7 @@ class Label(AbstractComponent, prop.IProperty, prop.IViewer,
         self.fireValueChange()
 
 
-    def __eq__(self, other):
+    def compareTo(self, other):
         """Compares the Label to other objects.
 
         Labels can be compared to other labels for sorting label contents.
@@ -403,7 +399,7 @@ class Label(AbstractComponent, prop.IProperty, prop.IViewer,
         else:
             otherValue = str(other)
 
-        return thisValue == otherValue
+        return cmp(thisValue, otherValue)
 
 
     def stripTags(self, xml):
